@@ -6,11 +6,14 @@ OC.L10N.register(
     "Delete" : "Padam",
     "New" : "Baru",
     "Cancel" : "Batal",
+    "Shared with you" : "Shared with you",
+    "Files" : "Fail",
     "Import" : "Import",
     "Export" : "Eksport",
     "Title" : "Judul",
     "Link" : "Link",
     "Notes" : "Nota",
+    "Open file" : "Buka fail",
     "Owner" : "Owner",
     "Share link" : "Share link",
     "Folder" : "Folder",
