@@ -5,6 +5,8 @@ OC.L10N.register(
     "Move" : "Ko'chiring",
     "Delete" : "O'chir",
     "Cancel" : "Bekor qilish",
+    "Shared with you" : "Siz bilan baham ko'rdim",
+    "Files" : "Fayllar",
     "Link" : "Ulanish",
     "Tags" : "Teglar",
     "Notes" : "Eslatmalar",
