@@ -27,6 +27,7 @@ OC.L10N.register(
     "Someone unshared folder \"%s\" with you" : "有人取消了开放给您的%s文件夹共享",
     "No file provided for import" : "未提供导入文件",
     "Unsupported file type for import" : "不支持导入的文件类型",
+    "Bookmarks Backups" : "书签备份",
     "Bookmarks shared by %s" : "书签共享者 %s",
     "Frequent bookmarks" : "常用书签",
     "Recent bookmarks" : "近期书签",
@@ -42,10 +43,12 @@ OC.L10N.register(
     "Select bookmark" : "选择书签",
     "Details" : "详情",
     "Rename" : "重命名",
+    "Copy link" : "复制链接",
     "Move" : "移动",
     "Add to folders" : "添加到文件夹",
     "Delete" : "删除",
     "Do you really want to delete this bookmark?" : "你真想删除这个书签吗？",
+    "Link copied to clipboard" : "链接已复制到剪贴板",
     "Content pending" : "内容待定",
     "This content is being downloaded for offline use. Please check back later." : "此内容正被下载以供离线使用。请稍后再来查看。 ",
     "Bookmarks to files on the web like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "网络上的文件，类似照片或 PDF 等的书签会被自动保存到你的Nextcloud 文件中，这样即使链接的文件消失，你仍然可以找到它们。",
@@ -147,7 +150,6 @@ OC.L10N.register(
     "Select a user or group" : "选择用户或分组",
     "Share link" : "共享链接",
     "Reading allowed" : "已允许读取",
-    "Copy link" : "复制链接",
     "Copy RSS feed" : "复制RSS提要",
     "Delete link" : "删除链接",
     "Create public link" : "生成公开链接地址",
